%define major		8
%define libname		%mklibname cryptopp %{major}
%define develname	%mklibname cryptopp -d

%define fver		%(echo %version |sed s/\\\\.//g)

%ifarch %{arm}
%define enable_tests	0
%else
%define enable_tests	1
%endif

Name:		libcryptopp
Version:	8.2.0
Release:	%mkrel 2
Summary:	C++ class library of cryptographic schemes
License:	Boost Software License 1.0
Group:		System/Libraries
URL:		http://www.cryptopp.com
Source0:	http://www.cryptopp.com/cryptopp%{fver}.zip
Source1:	cryptopp.pc
Source2:	cryptest.1
Patch0:		cryptopp-autotools.patch
Patch1:		CVE-2019-14318.patch
BuildRequires:	doxygen
%ifarch %{ix86} x86_64
BuildRequires:  nasm
%endif

%description
Crypto++ Library is a C++ class library of cryptographic schemes.
Currently the library consists of the following features:

    * AES(Rijndael) and AES candidates: RC6, MARS, Twofish, Serpent,
      CAST-256
    * other symmetric block ciphers: IDEA, DES, Triple-DES (DES-EDE2
      and DES-EDE3), DESX (DES-XEX3), RC2, RC5, Blowfish, TEA, XTEA,
      SAFER, 3-WAY, GOST, SHARK, CAST-128, Square, Skipjack, Camellia,
      SHACAL-2
    * generic block cipher modes: ECB, CBC, CBC ciphertext stealing
      (CTS), CFB, OFB, counter mode (CTR)
    * stream ciphers: Salsa20, Panama, ARC4, SEAL, WAKE, WAKE-OFB,
      BlumBlumShub
    * public-key cryptography: RSA, DSA, ElGamal, Nyberg-Rueppel (NR),
      Rabin, Rabin-Williams (RW), LUC, LUCELG, DLIES (variants of
      DHAES), ESIGN
    * padding schemes for public-key systems: PKCS#1 v2.0, OAEP, PSS,
      PSSR, IEEE P1363 EMSA2 and EMSA5
    * key agreement schemes: Diffie-Hellman (DH), Unified
      Diffie-Hellman (DH2), Menezes-Qu-Vanstone (MQV), LUCDIF, XTR-DH
    * elliptic curve cryptography: ECDSA, ECNR, ECIES, ECDH, ECMQV
    * one-way hash functions: SHA-1, MD2, MD4, MD5, HAVAL, RIPEMD-128,
      RIPEMD-256, RIPEMD-160, RIPEMD-320, Tiger, SHA-2 (SHA-224,
      SHA-256, SHA-384, and SHA-512), Panama, WHIRLPOOL
    * message authentication codes: MD5-MAC, HMAC, XOR-MAC, CBC-MAC,
      DMAC, Two-Track-MAC
    * cipher constructions based on hash functions: Luby-Rackoff, MDC
    * pseudo random number generators (PRNG): ANSI X9.17 appendix C,
      PGP's RandPool
    * password based key derivation functions: PBKDF1 and PBKDF2 from
      PKCS #5
    * Shamir's secret sharing scheme and Rabin's information dispersal
      algorithm (IDA)
    * DEFLATE (RFC 1951) compression/decompression with gzip (RFC
      1952) and zlib (RFC 1950) format support
    * fast multi-precision integer (bignum) and polynomial operations,
    * finite field arithmetics, including GF(p) and GF(2^n)
    * prime number generation and verification
    * various miscellaneous modules such as base 64 coding and 32-bit CRC


%package -n %{libname}
Group:		System/Libraries
Summary:	Base shared library part of %{name}
Provides:	%{name} = %{version}-%{release}

%description -n %{libname}
Crypto++ Library is a free C++ class library of cryptographic schemes.

This package contains the library needed to run programs dynamically
linked with %{name}.

%package -n %{develname}
Summary:	Header files and development documentation for %{name}
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	%{_lib}cryptopp-devel = %{version}-%{release}
Provides:	cryptopp-devel = %{version}-%{release}

%description -n %{develname}
Crypto++ Library is a free C++ class library of cryptographic schemes.

This package contains the header files and development documentation
for %{name}.

%package progs
Summary:	Programs for manipulating %{name} routines
Group:		Development/Other
Requires:	%{libname} = %{version}-%{release}
Provides:	cryptopp-progs = %{version}-%{release}

%description progs
Crypto++ Library is a free C++ class library of cryptographic schemes.

This package contains programs for manipulating %{name} routines.

%prep
%setup -q -c
%patch1 -p1 -b .CVE-2019-14318

perl -pi -e 's/\r$//g' License.txt Readme.txt

%build
%ifarch %{ix86} x86_64
./rdrand-nasm.sh
%endif

%make_build -f	GNUmakefile \
		CXXFLAGS="%{optflags} -DNDEBUG -fPIC -DPIC" \
		LDFLAGS="%{ldflags}" \
		LDLIBS="-lpthread" \
		shared cryptest.exe

doxygen

%install
%make_install PREFIX="%{_prefix}" LIBDIR="%{_libdir}"

#we don't want these
find %{buildroot} -name '*.a' -delete

# Install the pkg-config file
install -D -m644 %{SOURCE1} %{buildroot}%{_libdir}/pkgconfig/cryptopp.pc

# Install the man page
install -D -m644 %{SOURCE2} %{buildroot}%{_mandir}/man1/cryptest.1

# Fill in the variables
sed -i "s|@PREFIX@|%{_prefix}|g" %{buildroot}%{_libdir}/pkgconfig/cryptopp.pc
sed -i "s|@LIBDIR@|%{_libdir}|g" %{buildroot}%{_libdir}/pkgconfig/cryptopp.pc
sed -i "s|@INCLUDEDIR@|%{_includedir}|g" %{buildroot}%{_libdir}/pkgconfig/cryptopp.pc
sed -i "s|@VERSION@|%{version}|g" %{buildroot}%{_libdir}/pkgconfig/cryptopp.pc

# Rename cryptest
mv %{buildroot}%{_bindir}/cryptest.exe %{buildroot}%{_bindir}/cryptest

%check
%if %{enable_tests}
./cryptest.exe v
%endif

%files -n %{libname}
%doc License.txt Readme.txt
%{_libdir}/%{name}.so.%{major}{,.*}

%files -n %{develname}
%doc html-docs/*
%{_includedir}/cryptopp/
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/cryptopp.pc

%files progs
%{_bindir}/cryptest
%{_datadir}/cryptopp/
%{_mandir}/man1/cryptest.1*


%changelog
* Tue Feb 18 2020 umeabot <umeabot> 8.2.0-2.mga8
+ Revision: 1538797
- Mageia 8 Mass Rebuild

* Tue Nov 26 2019 daviddavid <daviddavid> 8.2.0-1.mga8
+ Revision: 1463015
- new version: 8.2.0
- add patch to fix CVE-2019-14318 (mga#25759)

* Sun Sep 16 2018 daviddavid <daviddavid> 7.0.0-1.mga7
+ Revision: 1259204
- new version: 7.0.0
- now libmajor is 7
- use the upstream GNUmakefile
- remove merged upstream patches

* Tue Oct 10 2017 daviddavid <daviddavid> 5.6.5-4.mga7
+ Revision: 1170699
- rebuild for new gcc7

* Sun Jun 11 2017 wally <wally> 5.6.5-3.mga6
+ Revision: 1107534
- add patch from Gentoo to fix CVE-2017-9434 (mga#21029)

* Mon Jan 02 2017 neoclust <neoclust> 5.6.5-2.mga6
+ Revision: 1079570
- Install trap.h

* Thu Dec 29 2016 wally <wally> 5.6.5-1.mga6
+ Revision: 1078594
- new version 5.6.5
- drop upstreamed patches
- update autotools patch

* Wed Dec 28 2016 wally <wally> 5.6.3-6.mga6
+ Revision: 1078523
- fix version in pkgconfig .pc file
- drop unneeded epoch

* Fri Dec 16 2016 mrambo3501 <mrambo3501> 0:5.6.3-5.mga6
+ Revision: 1075708
- add upstream patch to fix CVE-2016-9939

* Fri Sep 16 2016 luigiwalser <luigiwalser> 0:5.6.3-4.mga6
+ Revision: 1053356
- add -DNDEBUG to CXXFLAGS to fix CVE-2016-7420

* Fri Jun 17 2016 daviddavid <daviddavid> 0:5.6.3-3.mga6
+ Revision: 1021845
- disable testsuite on ARM

* Fri Apr 22 2016 luigiwalser <luigiwalser> 0:5.6.3-2.mga6
+ Revision: 1005384
- fix paths of test files
- add cryptest man page from debian

* Fri Apr 15 2016 luigiwalser <luigiwalser> 0:5.6.3-1.mga6
+ Revision: 1002789
- 5.6.3
- sync patches with fedora
- add patches from fedora to fix CVE-2016-3995

* Thu Feb 11 2016 umeabot <umeabot> 0:5.6.2-7.mga6
+ Revision: 955452
- Mageia 6 Mass Rebuild

* Wed Aug 26 2015 daviddavid <daviddavid> 0:5.6.2-6.mga6
+ Revision: 869587
- rebuild for new gcc 5.2.1

* Mon Jul 20 2015 luigiwalser <luigiwalser> 0:5.6.2-5.mga6
+ Revision: 855770
- add patch from fedora to fix CVE-2015-2141

* Wed Oct 15 2014 umeabot <umeabot> 0:5.6.2-4.mga5
+ Revision: 747374
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0:5.6.2-3.mga5
+ Revision: 681391
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 0:5.6.2-2.mga4
+ Revision: 528071
- Mageia 4 Mass Rebuild

* Sat Jun 15 2013 wally <wally> 0:5.6.2-1.mga4
+ Revision: 443415
- new version 5.6.2
- sync patches with Fedora
- drop s390 patch as we don't support it
- clean .spec a bit

* Sat Jan 12 2013 umeabot <umeabot> 0:5.6.1-4.mga3
+ Revision: 356933
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jan 07 2013 tv <tv> 0:5.6.1-3.mga3
+ Revision: 341236
- shrink description

* Mon Jan 07 2013 sander85 <sander85> 0:5.6.1-2.mga3
+ Revision: 341137
- Fix build with GCC 4.7

* Sun May 08 2011 dmorgan <dmorgan> 0:5.6.1-1.mga1
+ Revision: 95944
- New version 5.6.1
- imported package libcryptopp


* Thu Oct 23 2008 Götz Waschk <waschk@mandriva.org> 0:5.5.2-3mdv2009.1
+ Revision: 296718
- really update to 5.5.2

* Fri Aug 08 2008 Thierry Vignaud <tvignaud@mandriva.com> 0:5.5.2-2mdv2009.0
+ Revision: 267807
- rebuild early 2009.0 package (before pixel changes)

* Thu Jun 12 2008 Götz Waschk <waschk@mandriva.org> 0:5.5.2-1mdv2009.0
+ Revision: 218494
- new version
- patch for gcc 4.3
- new devel name
- fix obsoletes

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Sep 17 2007 David Walluck <walluck@mandriva.org> 0:5.5.1-2mdv2008.0
+ Revision: 88832
- add some cryptopp Provides

* Sat Jun 02 2007 David Walluck <walluck@mandriva.org> 0:5.5.1-1mdv2008.0
+ Revision: 34430
- 5.5.1
- change so version to 6:0:0 to match Debian

* Sun May 06 2007 David Walluck <walluck@mandriva.org> 0:5.5-1mdv2008.0
+ Revision: 23769
- 5.5


* Mon Jan 29 2007 David Walluck <walluck@mandriva.org> 5.4-1mdv2007.0
+ Revision: 114844
- 5.4
- Import libcryptopp

* Fri May 19 2006 David Walluck <walluck@mandriva.org> 0:5.3-0.20060518.1mdk
- CVS (20060518)
- enable standard CXXFLAGS
- disable P4 and SSE2 optimizations on x86-64

* Tue Aug 16 2005 David Walluck <walluck@mandriva.org> 0:5.3-0.20050714.1mdk
- 5.3 (CVS 20050714)
- patch (from cryptopp mailing list) to compile with GCC4
- BuildRequires: doxygen

* Sun Nov 07 2004 David Walluck <walluck@mandrake.org> 5.2.1-2mdk
- add doc package containing API documentation
- disable all optimizations to prevent miscompilation
- [DIRM]
- no need to add the same docs to every package

* Sun Jul 25 2004 Pierre-Michel Theveny <pmth@free.fr> 5.2.1-1mdk
- Updated to 5.2.1
- Change compile options to pass cryptest on 5.2.1

* Thu Jul 15 2004 Pierre-Michel Theveny <pmth@free.fr> 5.2-1mdk
- Updated to 5.2

* Mon Mar 01 2004 Lenny Cartier <lenny@mandrakesoft.com> 5.1-1mdk
- from Pierre-Michel Theveny <pmth@free.fr> :
	- Fixed problem with broken library (do not use -O2 !)
	- Added patch for GNU autotools and libtool support
	- Added package progs

* Thu Feb 19 2004 Pierre-Michel Theveny <pmth@free.fr> 5.1-1mdk
- Ported to Mandrake 9.2
- Added shared library

* Wed Feb 18 2004 Ariano Bertacca <ariano@hirnriss.net> 5.1-1
- released libcryptopp-5.1-1

